==> apache-camel-2.21.3-src.zip: apache-camel-2.21.3/camel-core/src/test/java/org/apache/camel/component/file/FileSorterRefTest.java <==
/**
 * Licensed to the Apache Software Foundation (ASF) under one or more
 * contributor license agreements.  See the NOTICE file distributed with
 * this work for additional information regarding copyright ownership.
 * The ASF licenses this file to You under the Apache License, Version 2.0
 * (the "License"); you may not use this file except in compliance with
 * the License.  You may obtain a copy of the License at
 *
 *      http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
package org.apache.camel.component.file;

import java.util.Comparator;

import org.apache.camel.ContextTestSupport;
import org.apache.camel.Exchange;
import org.apache.camel.builder.RouteBuilder;
import org.apache.camel.component.mock.MockEndpoint;
import org.apache.camel.impl.JndiRegistry;

/**
 * Unit test for  the file sorter ref option
 */
public class FileSorterRefTest extends ContextTestSupport {

    private String fileUrl = "file://target/filesorter/?initialDelay=0&delay=10&sorter=#mySorter";

    @Override
    public boolean isUseRouteBuilder() {
        return false;
    }

    @Override
    protected JndiRegistry createRegistry() throws Exception {
        JndiRegistry jndi = super.createRegistry();
        jndi.bind("mySorter", new MyFileSorter<Object>());
        return jndi;
    }

    @Override
    protected void setUp() throws Exception {
        deleteDirectory("target/filesorter");
        super.setUp();

        template.sendBodyAndHeader("file:target/filesorter/", "Hello Paris",
            Exchange.FILE_NAME, "paris.txt");

        template.sendBodyAndHeader("file:target/filesorter/", "Hello London",
            Exchange.FILE_NAME, "london.txt");

        template.sendBodyAndHeader("file:target/filesorter/", "Hello Copenhagen",
            Exchange.FILE_NAME, "copenhagen.txt");
    }

    public void testSortFiles() throws Exception {
        context.addRoutes(new RouteBuilder() {
            @Override
            public void configure() throws Exception {
                from(fileUrl).convertBodyTo(String.class).to("mock:result");
            }
        });
        context.start();

        MockEndpoint mock = getMockEndpoint("mock:result");
        mock.expectedBodiesReceived("Hello Copenhagen", "Hello London", "Hello Paris");
        assertMockEndpointsSatisfied();
    }

    // START SNIPPET: e1
    public class MyFileSorter<T> implements Comparator<GenericFile<T>> {
        public int compare(GenericFile<T> o1, GenericFile<T> o2) {
            return o1.getFileName().compareToIgnoreCase(o2.getFileName());
        }
    }
    // END SNIPPET: e1

}

==> apache-camel-2.22.2-src.zip: apache-camel-2.22.2/camel-core/src/test/java/org/apache/camel/component/file/FileSorterRefTest.java <==
/**
 * Licensed to the Apache Software Foundation (ASF) under one or more
 * contributor license agreements.  See the NOTICE file distributed with
 * this work for additional information regarding copyright ownership.
 * The ASF licenses this file to You under the Apache License, Version 2.0
 * (the "License"); you may not use this file except in compliance with
 * the License.  You may obtain a copy of the License at
 *
 *      http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
package org.apache.camel.component.file;

import java.util.Comparator;

import org.apache.camel.ContextTestSupport;
import org.apache.camel.Exchange;
import org.apache.camel.builder.RouteBuilder;
import org.apache.camel.component.mock.MockEndpoint;
import org.apache.camel.impl.JndiRegistry;

/**
 * Unit test for  the file sorter ref option
 */
public class FileSorterRefTest extends ContextTestSupport {

    private String fileUrl = "file://target/filesorter/?initialDelay=0&delay=10&sorter=#mySorter";

    @Override
    public boolean isUseRouteBuilder() {
        return false;
    }

    @Override
    protected JndiRegistry createRegistry() throws Exception {
        JndiRegistry jndi = super.createRegistry();
        jndi.bind("mySorter", new MyFileSorter<>());
        return jndi;
    }

    @Override
    protected void setUp() throws Exception {
        deleteDirectory("target/filesorter");
        super.setUp();

        template.sendBodyAndHeader("file:target/filesorter/", "Hello Paris",
            Exchange.FILE_NAME, "paris.txt");

        template.sendBodyAndHeader("file:target/filesorter/", "Hello London",
            Exchange.FILE_NAME, "london.txt");

        template.sendBodyAndHeader("file:target/filesorter/", "Hello Copenhagen",
            Exchange.FILE_NAME, "copenhagen.txt");
    }

    public void testSortFiles() throws Exception {
        context.addRoutes(new RouteBuilder() {
            @Override
            public void configure() throws Exception {
                from(fileUrl).convertBodyTo(String.class).to("mock:result");
            }
        });
        context.start();

        MockEndpoint mock = getMockEndpoint("mock:result");
        mock.expectedBodiesReceived("Hello Copenhagen", "Hello London", "Hello Paris");
        assertMockEndpointsSatisfied();
    }

    // START SNIPPET: e1
    public class MyFileSorter<T> implements Comparator<GenericFile<T>> {
        public int compare(GenericFile<T> o1, GenericFile<T> o2) {
            return o1.getFileName().compareToIgnoreCase(o2.getFileName());
        }
    }
    // END SNIPPET: e1

}
